@@ -26,7 +26,7 @@
 #include <stdint.h>
 #include <math.h>
 
-#define PYO_VERSION "1.0.4"
+#define PYO_VERSION "1.0.5"
 
 typedef Py_ssize_t T_SIZE_T;
 
@@ -644,9 +644,7 @@ extern PyTypeObject MMLZStreamType;
     if (self->server != NULL) \
         Py_VISIT(self->server); \
     Py_VISIT(self->mul); \
-    Py_VISIT(self->mul_stream); \
     Py_VISIT(self->add); \
-    Py_VISIT(self->add_stream);
 
 #define pyo_table_VISIT \
     if (self->server != NULL) \
@@ -687,27 +685,45 @@ extern PyTypeObject MMLZStreamType;
     }
 
 /* INIT INPUT STREAM */
+/* self->input should never be a floating-point object. The assigment from PyFloat_FromDouble
+   only serve to initialize the variable and increase its refcnt to 1, before replacing it with
+   the actual audio object.
+*/
 #define INIT_INPUT_STREAM \
     if ( PyObject_HasAttrString((PyObject *)inputtmp, "server") == 0 ) { \
         PyErr_SetString(PyExc_TypeError, "\"input\" argument must be a PyoObject.\n"); \
         Py_RETURN_NONE; \
     } \
-    Py_INCREF(inputtmp); \
-    Py_XDECREF(self->input); \
     self->input = inputtmp; \
+    Py_INCREF(self->input); \
     input_streamtmp = PyObject_CallMethod((PyObject *)self->input, "_getStream", NULL); \
-    Py_INCREF(input_streamtmp); \
-    Py_XDECREF(self->input_stream); \
-    self->input_stream = (Stream *)input_streamtmp;
+    self->input_stream = (Stream *)input_streamtmp; \
+    Py_INCREF(self->input_stream);
 
 #define INIT_INPUT_TRIGGER_STREAM \
-    Py_INCREF(inputtmp); \
-    Py_XDECREF(self->input); \
+    if ( PyObject_HasAttrString((PyObject *)inputtmp, "server") == 0 ) { \
+        PyErr_SetString(PyExc_TypeError, "\"input\" argument must be a PyoObject.\n"); \
+        Py_RETURN_NONE; \
+    } \
     self->input = inputtmp; \
+    Py_INCREF(self->input); \
     input_streamtmp = PyObject_CallMethod((PyObject *)self->input, "_getTriggerStream", NULL); \
-    Py_INCREF(input_streamtmp); \
-    Py_XDECREF(self->input_stream); \
-    self->input_stream = (TriggerStream *)input_streamtmp;
+    self->input_stream = (TriggerStream *)input_streamtmp; \
+    Py_INCREF(self->input_stream);
+
+#define INIT_INPUT_PV_STREAM \
+    self->input = inputtmp; \
+    Py_INCREF(self->input); \
+    input_streamtmp = PyObject_CallMethod((PyObject *)self->input, "_getPVStream", NULL); \
+    self->input_stream = (PVStream *)input_streamtmp; \
+    Py_INCREF(self->input_stream);
+
+#define INIT_INPUT2_PV_STREAM \
+    self->input2 = input2tmp; \
+    Py_INCREF(self->input2); \
+    input2_streamtmp = PyObject_CallMethod((PyObject *)self->input2, "_getPVStream", NULL); \
+    self->input2_stream = (PVStream *)input2_streamtmp; \
+    Py_INCREF(self->input2_stream);
 
 /* Init Server & Stream */
 #define INIT_OBJECT_COMMON \
@@ -734,7 +750,8 @@ extern PyTypeObject MMLZStreamType;
     Stream_setStreamObject(self->stream, (PyObject *)self); \
     Stream_setStreamId(self->stream, Stream_getNewStreamId()); \
     Stream_setBufferSize(self->stream, self->bufsize); \
-    Stream_setData(self->stream, self->data);
+    Stream_setData(self->stream, self->data); \
+    Py_INCREF(self->stream);
 
 #define SET_INTERP_POINTER \
     if (self->interp == 0) \
@@ -753,7 +770,7 @@ extern PyTypeObject MMLZStreamType;
     T_SIZE_T i; \
     if (! PyList_Check(arg)) { \
         PyErr_SetString(PyExc_TypeError, "The data must be a list of floats."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
     self->size = (T_SIZE_T)PyList_Size(arg); \
     self->data = (MYFLT *)PyMem_RawRealloc(self->data, (self->size+1) * sizeof(MYFLT)); \
@@ -773,7 +790,7 @@ extern PyTypeObject MMLZStreamType;
  \
     if (! PyList_Check(arg)) { \
         PyErr_SetString(PyExc_TypeError, "The data must be a list of list of floats."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
     for (i = 0; i < (self->height + 1); i++) { \
         PyMem_RawFree(self->data[i]); \
@@ -971,16 +988,16 @@ extern PyTypeObject MMLZStreamType;
     T_SIZE_T i; \
     if (arg == NULL) { \
         PyErr_SetString(PyExc_TypeError, "Cannot delete the list attribute."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
     if (! PyList_Check(arg)) { \
         PyErr_SetString(PyExc_TypeError, "arg must be a list."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
     int size = PyList_Size(arg); \
     if (size != self->size) { \
         PyErr_SetString(PyExc_TypeError, "New table must be of the same size as actual table."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
     for (i=0; i<self->size; i++) { \
         self->data[i] = PyFloat_AsDouble(PyList_GET_ITEM(arg, i)); \
@@ -1008,16 +1025,16 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"size", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "O", kwlist, &sizetmp)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     if (sizetmp) { \
         if (PyTuple_Check(sizetmp)) { \
-            w = PyInt_AsLong(PyTuple_GET_ITEM(sizetmp, 0)); \
-            h = PyInt_AsLong(PyTuple_GET_ITEM(sizetmp, 1)); \
+            w = PyLong_AsLong(PyTuple_GET_ITEM(sizetmp, 0)); \
+            h = PyLong_AsLong(PyTuple_GET_ITEM(sizetmp, 1)); \
         } \
         else if (PyList_Check(sizetmp)) { \
-            w = PyInt_AsLong(PyList_GET_ITEM(sizetmp, 0)); \
-            h = PyInt_AsLong(PyList_GET_ITEM(sizetmp, 1)); \
+            w = PyLong_AsLong(PyList_GET_ITEM(sizetmp, 0)); \
+            h = PyLong_AsLong(PyList_GET_ITEM(sizetmp, 1)); \
         } \
         else { \
             w = 500; \
@@ -1036,8 +1053,8 @@ extern PyTypeObject MMLZStreamType;
     for (i=0; i<w; i++) { \
         y = self->data[(T_SIZE_T)(i * step)] * amp + amp + 2; \
         tuple = PyTuple_New(2); \
-        PyTuple_SetItem(tuple, 0, PyInt_FromLong(i)); \
-        PyTuple_SetItem(tuple, 1, PyInt_FromLong(h-y)); \
+        PyTuple_SetItem(tuple, 0, PyLong_FromLong(i)); \
+        PyTuple_SetItem(tuple, 1, PyLong_FromLong(h-y)); \
         PyList_SetItem(samples, i, tuple); \
     } \
  \
@@ -1103,7 +1120,7 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"pos", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "n", kwlist, &pos)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     pos = -pos; \
     while (pos > self->size) pos -= self->size; \
@@ -1141,7 +1158,7 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"table", "srcpos", "destpos", "length", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "O|nnn", kwlist, &tabletmp, &srcpos, &destpos, &length)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     if ( PyObject_HasAttrString((PyObject *)tabletmp, "getTableStream") == 1 ) { \
         Py_XDECREF(table); \
@@ -1150,7 +1167,7 @@ extern PyTypeObject MMLZStreamType;
  \
         if (srcpos < -tabsize || srcpos >= tabsize) { \
             PyErr_SetString(PyExc_IndexError, "PyoTableObject: Position outside of table boundaries!."); \
-            return PyInt_FromLong(-1); \
+            return PyLong_FromLong(-1); \
         } \
     \
         if (srcpos < 0) \
@@ -1159,7 +1176,7 @@ extern PyTypeObject MMLZStreamType;
  \
         if (destpos < -self->size || destpos >= self->size) { \
             PyErr_SetString(PyExc_IndexError, "PyoTableObject: Position outside of table boundaries!."); \
-            return PyInt_FromLong(-1); \
+            return PyLong_FromLong(-1); \
         } \
     \
         if (destpos < 0) \
@@ -1187,7 +1204,7 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"gpos", "gneg", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE__FF, kwlist, &gpos, &gneg)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     for (i=0; i<self->size+1; i++) { \
         if (self->data[i] < 0) \
@@ -1206,7 +1223,7 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"exp", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F, kwlist, &exp)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     for (i=0; i<self->size+1; i++) { \
         x = self->data[i]; \
@@ -1231,7 +1248,7 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"freq", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F, kwlist, &freq)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     b = 2.0 - MYCOS(TWOPI * freq / sr); \
     c = b - MYSQRT(b * b - 1.0); \
@@ -1254,7 +1271,7 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"dur", "shape", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F_I, kwlist, &dur, &shape)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     samp = (T_SIZE_T)(dur * sr + 0.5); \
     if (samp < 0 || samp >= self->size) \
@@ -1296,7 +1313,7 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"dur", "shape", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F_I, kwlist, &dur, &shape)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     samp = (T_SIZE_T)(dur * sr + 0.5); \
     if (samp < 0 || samp >= self->size) \
@@ -1337,7 +1354,7 @@ extern PyTypeObject MMLZStreamType;
  \
     static char *kwlist[] = {"level", NULL}; \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F, kwlist, &level)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     mi = ma = *self->data; \
     for (i=1; i<self->size; i++) { \
@@ -1366,7 +1383,7 @@ extern PyTypeObject MMLZStreamType;
  \
      static char *kwlist[] = {"level", NULL}; \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F, kwlist, &level)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     mi = ma = self->data[0][0]; \
     for (i=1; i<self->height; i++) { \
@@ -1399,11 +1416,11 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"value", "pos", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F_N, kwlist, &val, &pos)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     if (pos < -self->size || pos >= self->size) { \
         PyErr_SetString(PyExc_IndexError, "PyoTableObject: Position outside of table boundaries!."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
  \
     if (pos < 0) \
@@ -1418,11 +1435,11 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"pos", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "n", kwlist, &pos)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     if (pos < -self->size || pos >= self->size) { \
         PyErr_SetString(PyExc_IndexError, "PyoTableObject: Position outside of table boundaries!."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
  \
     if (pos < 0) \
@@ -1430,23 +1447,35 @@ extern PyTypeObject MMLZStreamType;
  \
     return PyFloat_FromDouble(self->data[pos]);
 
+#define TABLE_GET_RATE \
+    PyObject *srobj = PyObject_CallMethod(self->server, "getSamplingRate", NULL); \
+    double sr = PyFloat_AsDouble(srobj); \
+    Py_DECREF(srobj); \
+    return PyFloat_FromDouble((MYFLT)sr / self->size);
+
 #define TABLE_SET_SIZE \
     if (value == NULL) \
     { \
         PyErr_SetString(PyExc_TypeError, "Cannot delete the size attribute."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
  \
-    if (! PyInt_Check(value)) \
+    if (! PyLong_Check(value)) \
     { \
         PyErr_SetString(PyExc_TypeError, "The size attribute value must be an integer."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
  \
-    self->size = PyInt_AsLong(value); \
+    T_SIZE_T size = PyLong_AsLong(value); \
  \
-    self->data = (MYFLT *)PyMem_RawRealloc(self->data, (self->size + 1) * sizeof(MYFLT)); \
-    TableStream_setSize(self->tablestream, self->size);
+    MYFLT *data = (MYFLT *)PyMem_RawRealloc(self->data, (size + 1) * sizeof(MYFLT)); \
+    if (data != NULL) \
+    { \
+        self->data = data; \
+        self->size = size; \
+        TableStream_setData(self->tablestream, self->data); \
+        TableStream_setSize(self->tablestream, self->size); \
+    }
 
 #define TABLE_SET_SIZE_WITH_POINT_LIST \
     T_SIZE_T i, old_size, x1; \
@@ -1456,17 +1485,17 @@ extern PyTypeObject MMLZStreamType;
     if (value == NULL) \
     { \
         PyErr_SetString(PyExc_TypeError, "Cannot delete the size attribute."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
  \
-    if (! PyInt_Check(value)) \
+    if (! PyLong_Check(value)) \
     { \
         PyErr_SetString(PyExc_TypeError, "The size attribute value must be an integer."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
  \
     old_size = self->size; \
-    self->size = PyInt_AsLong(value); \
+    self->size = PyLong_AsLong(value); \
  \
     factor = (MYFLT)(self->size) / old_size; \
  \
@@ -1530,7 +1559,7 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"min", "max", "boost", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE__FFF, kwlist, &min, &max, &boost)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     float mid = (min + max) * 0.5; \
  \
@@ -1549,16 +1578,16 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"value", "x", "y", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_F_II, kwlist, &val, &x, &y)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     if (x >= self->width) { \
         PyErr_SetString(PyExc_TypeError, "X position outside of matrix boundaries!."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
  \
     if (y >= self->height) { \
         PyErr_SetString(PyExc_TypeError, "Y position outside of matrix boundaries!."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
  \
     self->data[y][x] = val; \
@@ -1577,16 +1606,16 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"x", "y", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "ii", kwlist, &x, &y)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     if (x >= self->width) { \
         PyErr_SetString(PyExc_TypeError, "X position outside of matrix boundaries!."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
  \
     if (y >= self->height) { \
         PyErr_SetString(PyExc_TypeError, "Y position outside of matrix boundaries!."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
  \
     return PyFloat_FromDouble(self->data[y][x]); \
@@ -1596,16 +1625,16 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"x", "y", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE__FF, kwlist, &x, &y)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     if (x < 0.0 || x > 1.0) { \
         PyErr_SetString(PyExc_TypeError, "X position outside of matrix boundaries!."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
  \
     if (y < 0.0 || y > 1.0) { \
         PyErr_SetString(PyExc_TypeError, "Y position outside of matrix boundaries!."); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
  \
     return PyFloat_FromDouble(MatrixStream_getInterpPointFromPos(self->matrixstream, x, y)); \
@@ -1614,7 +1643,7 @@ extern PyTypeObject MMLZStreamType;
 #define GET_SERVER \
     if (self->server == NULL) { \
         PyErr_SetString(PyExc_TypeError, "No server founded!"); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
     Py_INCREF(self->server); \
     return self->server;
@@ -1622,7 +1651,7 @@ extern PyTypeObject MMLZStreamType;
 #define GET_STREAM \
     if (self->stream == NULL) { \
         PyErr_SetString(PyExc_TypeError, "No stream founded!"); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
     Py_INCREF(self->stream); \
     return (PyObject *)self->stream;
@@ -1630,7 +1659,7 @@ extern PyTypeObject MMLZStreamType;
 #define GET_TRIGGER_STREAM \
     if (self->trig_stream == NULL) { \
         PyErr_SetString(PyExc_TypeError, "No trigger stream founded!"); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
     Py_INCREF(self->trig_stream); \
     return (PyObject *)self->trig_stream;
@@ -1638,7 +1667,7 @@ extern PyTypeObject MMLZStreamType;
 #define GET_TABLE_STREAM \
     if (self->tablestream == NULL) { \
         PyErr_SetString(PyExc_TypeError, "No table stream founded!"); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
     Py_INCREF(self->tablestream); \
     return (PyObject *)self->tablestream; \
@@ -1646,7 +1675,7 @@ extern PyTypeObject MMLZStreamType;
 #define GET_MATRIX_STREAM \
     if (self->matrixstream == NULL) { \
         PyErr_SetString(PyExc_TypeError, "No matrix stream founded!"); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
     Py_INCREF(self->matrixstream); \
     return (PyObject *)self->matrixstream; \
@@ -1654,38 +1683,32 @@ extern PyTypeObject MMLZStreamType;
 #define GET_PV_STREAM \
     if (self->pv_stream == NULL) { \
         PyErr_SetString(PyExc_TypeError, "No pv stream founded!"); \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
     } \
     Py_INCREF(self->pv_stream); \
     return (PyObject *)self->pv_stream;
 
 #define SET_MUL \
-    PyObject *tmp, *streamtmp; \
- \
     if (arg == NULL) { \
         Py_RETURN_NONE; \
     } \
  \
-    int isNumber = PyNumber_Check(arg); \
- \
-    tmp = arg; \
-    Py_INCREF(tmp); \
     Py_DECREF(self->mul); \
-    if (isNumber == 1) { \
-        self->mul = PyNumber_Float(tmp); \
+ \
+    if (PyNumber_Check(arg)) { \
+        self->mul = PyNumber_Float(arg); \
         self->modebuffer[0] = 0; \
     } \
     else { \
-        self->mul = tmp; \
+        self->mul = arg; \
+        Py_INCREF(self->mul); \
         if (! PyObject_HasAttrString((PyObject *)self->mul, "_getStream")) { \
             PyErr_SetString(PyExc_ArithmeticError, "Only number or audio internal object can be used in arithmetic with audio internal objects.\n"); \
             PyErr_Print(); \
         } \
-        Py_INCREF(self->mul); \
-        streamtmp = PyObject_CallMethod((PyObject *)self->mul, "_getStream", NULL); \
-        Py_INCREF(streamtmp); \
-        Py_XDECREF(self->mul_stream); \
+        PyObject *streamtmp = PyObject_CallMethod((PyObject *)self->mul, "_getStream", NULL); \
         self->mul_stream = (Stream *)streamtmp; \
+        Py_INCREF(self->mul_stream); \
         self->modebuffer[0] = 1; \
     } \
  \
@@ -1694,32 +1717,26 @@ extern PyTypeObject MMLZStreamType;
     Py_RETURN_NONE;
 
 #define SET_ADD \
-    PyObject *tmp, *streamtmp; \
-\
     if (arg == NULL) { \
         Py_RETURN_NONE; \
     } \
 \
-    int isNumber = PyNumber_Check(arg); \
-\
-    tmp = arg; \
-    Py_INCREF(tmp); \
     Py_DECREF(self->add); \
-    if (isNumber == 1) { \
-        self->add = PyNumber_Float(tmp); \
+ \
+    if (PyNumber_Check(arg)) { \
+        self->add = PyNumber_Float(arg); \
         self->modebuffer[1] = 0; \
     } \
     else { \
-        self->add = tmp; \
+        self->add = arg; \
+        Py_INCREF(self->add); \
         if (! PyObject_HasAttrString((PyObject *)self->add, "_getStream")) { \
             PyErr_SetString(PyExc_ArithmeticError, "Only number or audio internal object can be used in arithmetic with audio internal objects.\n"); \
             PyErr_Print(); \
         } \
-        Py_INCREF(self->add); \
-        streamtmp = PyObject_CallMethod((PyObject *)self->add, "_getStream", NULL); \
-        Py_INCREF(streamtmp); \
-        Py_XDECREF(self->add_stream); \
+        PyObject *streamtmp = PyObject_CallMethod((PyObject *)self->add, "_getStream", NULL); \
         self->add_stream = (Stream *)streamtmp; \
+        Py_INCREF(self->add_stream); \
         self->modebuffer[1] = 1; \
     } \
 \
@@ -1728,32 +1745,27 @@ extern PyTypeObject MMLZStreamType;
     Py_RETURN_NONE;
 
 #define SET_SUB \
-    PyObject *tmp, *streamtmp; \
- \
     if (arg == NULL) { \
         Py_RETURN_NONE; \
     } \
  \
-    int isNumber = PyNumber_Check(arg); \
- \
-    tmp = arg; \
-    Py_INCREF(tmp); \
     Py_DECREF(self->add); \
-    if (isNumber == 1) { \
-        self->add = PyFloat_FromDouble(PyFloat_AsDouble(tmp) * -1.0); \
+ \
+    if (PyNumber_Check(arg)) { \
+        double tmp = PyFloat_AsDouble(arg); \
+        self->add = PyFloat_FromDouble(tmp * -1.0); \
         self->modebuffer[1] = 0; \
     } \
     else { \
-        self->add = tmp; \
+        self->add = arg; \
+        Py_INCREF(self->add); \
         if (! PyObject_HasAttrString((PyObject *)self->add, "_getStream")) { \
             PyErr_SetString(PyExc_ArithmeticError, "Only number or audio internal object can be used in arithmetic with audio internal objects.\n"); \
             PyErr_Print(); \
         } \
-        Py_INCREF(self->add); \
-        streamtmp = PyObject_CallMethod((PyObject *)self->add, "_getStream", NULL); \
-        Py_INCREF(streamtmp); \
-        Py_XDECREF(self->add_stream); \
+        PyObject *streamtmp = PyObject_CallMethod((PyObject *)self->add, "_getStream", NULL); \
         self->add_stream = (Stream *)streamtmp; \
+        Py_INCREF(self->add_stream); \
         self->modebuffer[1] = 2; \
     } \
  \
@@ -1762,35 +1774,28 @@ extern PyTypeObject MMLZStreamType;
     Py_RETURN_NONE;
 
 #define SET_DIV \
-    PyObject *tmp, *streamtmp; \
- \
     if (arg == NULL) { \
         Py_RETURN_NONE; \
     } \
  \
-    int isNumber = PyNumber_Check(arg); \
- \
-    tmp = arg; \
-    Py_INCREF(tmp); \
-    if (isNumber == 1) { \
-        if (PyFloat_AsDouble(tmp) != 0.) { \
+    if (PyNumber_Check(arg)) { \
+        if (PyFloat_AsDouble(arg) != 0.) { \
             Py_DECREF(self->mul); \
-            self->mul = PyFloat_FromDouble(1.0 / PyFloat_AsDouble(tmp)); \
+            self->mul = PyFloat_FromDouble(1.0 / PyFloat_AsDouble(arg)); \
             self->modebuffer[0] = 0; \
         } \
     } \
     else { \
         Py_DECREF(self->mul); \
-        self->mul = tmp; \
+        self->mul = arg; \
+        Py_INCREF(self->mul); \
         if (! PyObject_HasAttrString((PyObject *)self->mul, "_getStream")) { \
             PyErr_SetString(PyExc_ArithmeticError, "Only number or audio internal object can be used in arithmetic with audio internal objects.\n"); \
             PyErr_Print(); \
         } \
-        Py_INCREF(self->mul); \
-        streamtmp = PyObject_CallMethod((PyObject *)self->mul, "_getStream", NULL); \
-        Py_INCREF(streamtmp); \
-        Py_XDECREF(self->mul_stream); \
+        PyObject *streamtmp = PyObject_CallMethod((PyObject *)self->mul, "_getStream", NULL); \
         self->mul_stream = (Stream *)streamtmp; \
+        Py_INCREF(self->mul_stream); \
         self->modebuffer[0] = 2; \
     } \
  \
@@ -1798,19 +1803,42 @@ extern PyTypeObject MMLZStreamType;
  \
     Py_RETURN_NONE;
 
+#define SET_PARAM(param, paramstream, modebufpos) \
+    if (arg == NULL) { \
+        Py_RETURN_NONE; \
+    } \
+ \
+    Py_DECREF(param); \
+ \
+    if (PyNumber_Check(arg)) { \
+        param = PyNumber_Float(arg); \
+        self->modebuffer[modebufpos] = 0; \
+    } \
+    else { \
+        param = arg; \
+        Py_INCREF(param); \
+        PyObject *streamtmp = PyObject_CallMethod((PyObject *)param, "_getStream", NULL); \
+        paramstream = (Stream *)streamtmp; \
+        Py_INCREF(paramstream); \
+        self->modebuffer[modebufpos] = 1; \
+    } \
+ \
+    (*self->mode_func_ptr)(self); \
+ \
+    Py_RETURN_NONE;
+
 /* Multiply, Add, inplace_multiply & inplace_add */
 #define MULTIPLY \
     Dummy *dummy; \
     MAKE_NEW_DUMMY(dummy, &DummyType, NULL); \
     Dummy_initialize(dummy); \
     PyObject_CallMethod((PyObject *)dummy, "setMul", "O", arg); \
-    Py_DECREF(arg); \
     PyObject_CallMethod((PyObject *)dummy, "setInput", "O", self); \
+    Py_INCREF(dummy); \
     return (PyObject *)dummy;
 
 #define INPLACE_MULTIPLY \
     PyObject_CallMethod((PyObject *)self, "setMul", "O", arg); \
-    Py_DECREF(arg); \
     Py_INCREF(self); \
     return (PyObject *)self;
 
@@ -1819,13 +1847,12 @@ extern PyTypeObject MMLZStreamType;
     MAKE_NEW_DUMMY(dummy, &DummyType, NULL); \
     Dummy_initialize(dummy); \
     PyObject_CallMethod((PyObject *)dummy, "setAdd", "O", arg); \
-    Py_DECREF(arg); \
     PyObject_CallMethod((PyObject *)dummy, "setInput", "O", self); \
+    Py_INCREF(dummy); \
     return (PyObject *)dummy;
 
 #define INPLACE_ADD \
     PyObject_CallMethod((PyObject *)self, "setAdd", "O", arg); \
-    Py_DECREF(arg); \
     Py_INCREF(self); \
     return (PyObject *)self;
 
@@ -1834,13 +1861,12 @@ extern PyTypeObject MMLZStreamType;
     MAKE_NEW_DUMMY(dummy, &DummyType, NULL); \
     Dummy_initialize(dummy); \
     PyObject_CallMethod((PyObject *)dummy, "setSub", "O", arg); \
-    Py_DECREF(arg); \
     PyObject_CallMethod((PyObject *)dummy, "setInput", "O", self); \
+    Py_INCREF(dummy); \
     return (PyObject *)dummy;
 
 #define INPLACE_SUB \
     PyObject_CallMethod((PyObject *)self, "setSub", "O", arg); \
-    Py_DECREF(arg); \
     Py_INCREF(self); \
     return (PyObject *)self;
 
@@ -1849,13 +1875,12 @@ extern PyTypeObject MMLZStreamType;
     MAKE_NEW_DUMMY(dummy, &DummyType, NULL); \
     Dummy_initialize(dummy); \
     PyObject_CallMethod((PyObject *)dummy, "setDiv", "O", arg); \
-    Py_DECREF(arg); \
     PyObject_CallMethod((PyObject *)dummy, "setInput", "O", self); \
+    Py_INCREF(dummy); \
     return (PyObject *)dummy;
 
 #define INPLACE_DIV \
     PyObject_CallMethod((PyObject *)self, "setDiv", "O", arg); \
-    Py_DECREF(arg); \
     Py_INCREF(self); \
     return (PyObject *)self;
 
@@ -1871,7 +1896,7 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"dur", "delay", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "|ff", kwlist, &dur, &del)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     PyObject *delobj = PyObject_CallMethod(self->server, "getGlobalDel", NULL); \
     PyObject *durobj = PyObject_CallMethod(self->server, "getGlobalDur", NULL); \
@@ -1924,7 +1949,7 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"chnl", "dur", "delay", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "|iff", kwlist, &chnltmp, &dur, &del)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     PyObject *delobj = PyObject_CallMethod(self->server, "getGlobalDel", NULL); \
     PyObject *durobj = PyObject_CallMethod(self->server, "getGlobalDur", NULL); \
@@ -1973,7 +1998,7 @@ extern PyTypeObject MMLZStreamType;
     static char *kwlist[] = {"wait", NULL}; \
  \
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "|f", kwlist, &wait)) \
-        return PyInt_FromLong(-1); \
+        return PyLong_FromLong(-1); \
  \
     if (wait == 0) { \
         Stream_setStreamActive(self->stream, 0); \
@@ -2102,21 +2127,6 @@ extern PyTypeObject MMLZStreamType;
     }
 
 /* Tables buffer protocol. */
-#if PY_MAJOR_VERSION < 3
-#define TABLESTREAM_READ_WRITE_BUFFER \
-    if ( index != 0 ) { \
-        PySys_WriteStdout("Pyo error: Table buffer, accessing non-existent bytes segment."); \
-        return -1; \
-    } \
-    *ptr = (void *)self->data; \
-    return (Py_ssize_t)self->size * sizeof(MYFLT);
-
-#define TABLESTREAM_SEG_COUNT \
-    if ( lenp ) \
-        *lenp = (Py_ssize_t)self->size * sizeof(MYFLT); \
-    return 1;
-#endif
-
 #define TABLESTREAM_GET_BUFFER \
     if (view == NULL) { \
         PySys_WriteStdout("Pyo error: Table buffer, NULL view in getBuffer."); \
