@@ -26,7 +26,6 @@ rec.setValue("/4/xy", [0.5, 0.5])
 
 # Assign the value on the X axis to the drive parameter, and
 # the value on the Y axis to the slope (lowpass filter) parameter.
-disto = Disto(source, drive=Sqrt(rec["/4/xy"][0]),
-              slope=Sqrt(rec["/4/xy"][1]), mul=0.5).mix(2).out()
+disto = Disto(source, drive=Sqrt(rec["/4/xy"][0]), slope=Sqrt(rec["/4/xy"][1]), mul=0.5).mix(2).out()
 
-s.gui(locals())
\ No newline at end of file
+s.gui(locals())
