@@ -1,7 +1,3 @@
-from __future__ import division
-from __future__ import print_function
-from __future__ import absolute_import
-
 """
 Copyright 2009-2015 Olivier Belanger
 
@@ -291,9 +287,11 @@ class TriangleTable(PyoTableObject):
         PyoTableObject.__init__(self, size)
         self._order = order
         list = []
+        ph = 1.0
         for i in range(1, (order * 2)):
             if i % 2 == 1:
-                list.append(1.0 / pow(i, 2))
+                list.append(ph / pow(i, 2))
+                ph *= -1
             else:
                 list.append(0.0)
         self._base_objs = [HarmTable_base(list, size)]
@@ -311,9 +309,11 @@ class TriangleTable(PyoTableObject):
         pyoArgsAssert(self, "I", x)
         self._order = x
         list = []
+        ph = 1.0
         for i in range(1, (self._order * 2)):
             if i % 2 == 1:
-                list.append(1.0 / pow(i, 2))
+                list.append(ph / pow(i, 2))
+                ph *= -1
             else:
                 list.append(0.0)
         [obj.replace(list) for obj in self._base_objs]
@@ -1647,7 +1647,7 @@ class SndTable(PyoTableObject):
             self._base_objs = [SndTable_base("", 0, 0) for i in range(initchnls)]
         else:
             for p in path:
-                _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(p)
+                _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(p, raise_on_failure=True)
                 if chnl is None:
                     if stop is None:
                         self._base_objs.extend([SndTable_base(stringencode(p), i, start) for i in range(_snd_chnls)])
@@ -1693,7 +1693,7 @@ class SndTable(PyoTableObject):
             path, lmax = convertArgsToLists(path)
             for i, obj in enumerate(self._base_objs):
                 p = path[i % lmax]
-                _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(p)
+                _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(p, raise_on_failure=True)
                 self._size.append(_size)
                 self._dur.append(_dur)
                 if stop is None:
@@ -1701,7 +1701,7 @@ class SndTable(PyoTableObject):
                 else:
                     obj.setSound(stringencode(p), 0, start, stop)
         else:
-            _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(path)
+            _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(path, raise_on_failure=True)
             self._size = _size
             self._dur = _dur
             if stop is None:
@@ -1743,7 +1743,7 @@ class SndTable(PyoTableObject):
             path, lmax = convertArgsToLists(path)
             for i, obj in enumerate(self._base_objs):
                 p = path[i % lmax]
-                _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(p)
+                _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(p, raise_on_failure=True)
                 self._size.append(_size)
                 self._dur.append(_dur)
                 if stop is None:
@@ -1751,7 +1751,7 @@ class SndTable(PyoTableObject):
                 else:
                     obj.append(stringencode(p), crossfade, 0, start, stop)
         else:
-            _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(path)
+            _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(path, raise_on_failure=True)
             self._size = _size
             self._dur = _dur
             if stop is None:
@@ -1801,7 +1801,7 @@ class SndTable(PyoTableObject):
             path, lmax = convertArgsToLists(path)
             for i, obj in enumerate(self._base_objs):
                 p = path[i % lmax]
-                _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(p)
+                _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(p, raise_on_failure=True)
                 self._size.append(_size)
                 self._dur.append(_dur)
                 if stop is None:
@@ -1809,7 +1809,7 @@ class SndTable(PyoTableObject):
                 else:
                     obj.insert(stringencode(p), pos, crossfade, 0, start, stop)
         else:
-            _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(path)
+            _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(path, raise_on_failure=True)
             self._size = _size
             self._dur = _dur
             if stop is None:
@@ -1824,85 +1824,6 @@ class SndTable(PyoTableObject):
                 ]
         self.refreshView()
 
-    def getRate(self, all=True):
-        """
-        Return the frequency in cps at which the sound will be read at its
-        original pitch.
-
-        :Args:
-
-            all: boolean
-                If the table contains more than one sound and `all` is True,
-                returns a list of all durations. Otherwise, returns only the
-                first duration as a float.
-
-        """
-        if type(self._path) == list:
-            _rate = [obj.getRate() for obj in self._base_objs]
-        else:
-            _rate = self._base_objs[0].getRate()
-
-        if all:
-            return _rate
-        else:
-            if type(_rate) == list:
-                return _rate[0]
-            else:
-                return _rate
-
-    def getDur(self, all=True):
-        """
-        Return the duration of the sound in seconds.
-
-        :Args:
-
-            all: boolean
-                If the table contains more than one sound and `all` is True,
-                returns a list of all durations. Otherwise, returns only the
-                first duration as a float.
-
-        """
-        if type(self._path) == list:
-            _dur = [1.0 / obj.getRate() for obj in self._base_objs]
-        else:
-            _dur = 1.0 / self._base_objs[0].getRate()
-
-        if all:
-            return _dur
-        else:
-            if type(_dur) == list:
-                return _dur[0]
-            else:
-                return _dur
-
-    def setSize(self, x):
-        print("SndTable has no setSize method!")
-
-    def getSize(self, all=True):
-        """
-        Return the size of the table in samples.
-
-        :Args:
-
-            all: boolean
-                If the table contains more than one sound and `all` is True,
-                returns a list of all sizes. Otherwise, returns only the
-                first size as an int.
-
-        """
-        if len(self._base_objs) > 1:
-            _size = [obj.getSize() for obj in self._base_objs]
-        else:
-            _size = self._base_objs[0].getSize()
-
-        if all:
-            return _size
-        else:
-            if type(_size) == list:
-                return _size[0]
-            else:
-                return _size
-
     def getViewTable(self, size, begin=0, end=0):
         """
         Return a list of points (in X, Y pixel values) for each channel in the table.
@@ -2126,6 +2047,31 @@ class NewTable(PyoTableObject):
         self._feedback = x
         [obj.setFeedback(x) for i, obj in enumerate(self._base_objs)]
 
+    def setLength(self, length):
+        """
+        Change the length of the table.
+
+        If the new length is longer than the current one, new samples will
+        be initialized to 0.
+
+        :Args:
+
+            length: float
+                New table length in seconds.
+
+        """
+        pyoArgsAssert(self, "N", length)
+        self._length = length
+        [obj.setLength(length) for obj in self._base_objs]
+        self.refreshView()
+
+    def getFeedback(self):
+        """
+        Returns the current feedback value.
+
+        """
+        return self._feedback
+
     def getLength(self):
         """
         Returns the length of the table in seconds.
@@ -2133,24 +2079,6 @@ class NewTable(PyoTableObject):
         """
         return self._base_objs[0].getLength()
 
-    def getDur(self, all=True):
-        """
-        Returns the length of the table in seconds.
-
-        The `all` argument is there for compatibility with SndTable but
-        is not used for now.
-
-        """
-        return self._base_objs[0].getLength()
-
-    def getRate(self):
-        """
-        Returns the frequency (cycle per second) to give to an
-        oscillator to read the sound at its original pitch.
-
-        """
-        return self._base_objs[0].getRate()
-
     def getViewTable(self, size, begin=0, end=0):
         """
         Return a list of points (in X, Y pixel values) for each channel in the table.
@@ -2323,14 +2251,6 @@ class DataTable(PyoTableObject):
         [obj.setTable(self._check_data_size(wrap(x, i))) for i, obj in enumerate(self._base_objs)]
         self.refreshView()
 
-    def getRate(self):
-        """
-        Returns the frequency (cycle per second) to give to an
-        oscillator to read the sound at its original pitch.
-
-        """
-        return self._base_objs[0].getRate()
-
     def _get_current_data(self):
         # internal that returns the data to draw in a DataTableGrapher.
         return self.getTable()
@@ -2856,14 +2776,6 @@ class SharedTable(PyoTableObject):
         name, lmax = convertArgsToLists(name)
         self._base_objs = [SharedTable_base(wrap(name, i), create, size) for i in range(lmax)]
 
-    def getRate(self):
-        """
-        Returns the frequency (cycle per second) to give to an
-        oscillator to read the sound at its original pitch.
-
-        """
-        return self._base_objs[0].getRate()
-
     @property
     def size(self):
         """int. Length of the table in samples."""
