@@ -2,8 +2,6 @@
 Miscellaneous objects.
 
 """
-from __future__ import print_function
-from __future__ import absolute_import
 
 """
 Copyright 2009-2015 Olivier Belanger
