@@ -17,14 +17,7 @@ GNU Lesser General Public License for more details.
 You should have received a copy of the GNU Lesser General Public
 License along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 """
-import sys
-
-if sys.version_info[0] < 3:
-    import __builtin__
-
-    builtins = __builtin__
-else:
-    import builtins
+import builtins
 
 builtins.pyo_use_double = True
 
