@@ -19,7 +19,6 @@
  *************************************************************************/
 
 #include <Python.h>
-#include "py2to3.h"
 #include "structmember.h"
 #include <math.h>
 #include "pyomodule.h"
@@ -135,6 +134,13 @@ Dummy_dealloc(Dummy* self)
     Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
+static PyObject *
+Dummy_decref(Dummy* self)
+{
+    Py_DECREF(self); 
+    Py_RETURN_NONE;
+};
+
 PyObject *
 Dummy_initialize(Dummy *self)
 {
@@ -158,29 +164,22 @@ Dummy_initialize(Dummy *self)
 static PyObject *
 Dummy_setInput(Dummy *self, PyObject *arg)
 {
-    PyObject *tmp, *streamtmp;
-
     ASSERT_ARG_NOT_NULL
 
-    int isNumber = PyNumber_Check(arg);
+    Py_DECREF(self->input);
 
-    tmp = arg; // not sure anymore...
-    Py_INCREF(tmp);
-    Py_XDECREF(self->input);
-
-    if (isNumber == 1)
+    if (PyNumber_Check(arg))
     {
-        self->input = PyNumber_Float(tmp);
+        self->input = PyNumber_Float(arg);
         self->modebuffer[2] = 0;
     }
     else
     {
-        self->input = tmp;
+        self->input = arg;
         Py_INCREF(self->input);
-        streamtmp = PyObject_CallMethod((PyObject *)self->input, "_getStream", NULL);
-        Py_INCREF(streamtmp);
-        Py_XDECREF(self->input_stream);
+        PyObject *streamtmp = PyObject_CallMethod((PyObject *)self->input, "_getStream", NULL);
         self->input_stream = (Stream *)streamtmp;
+        Py_INCREF(self->input_stream);
         self->modebuffer[2] = 1;
     }
 
@@ -233,6 +232,7 @@ static PyMethodDef Dummy_methods[] =
     {"setAdd", (PyCFunction)Dummy_setAdd, METH_O, "Sets add factor."},
     {"setSub", (PyCFunction)Dummy_setSub, METH_O, "Sets inverse add factor."},
     {"setDiv", (PyCFunction)Dummy_setDiv, METH_O, "Sets inverse mul factor."},
+    {"decref", (PyCFunction)Dummy_decref, METH_NOARGS, "Decref self reference count."},
     {NULL}  /* Sentinel */
 };
 
@@ -241,7 +241,6 @@ static PyNumberMethods Dummy_as_number =
     (binaryfunc)Dummy_add,                         /*nb_add*/
     (binaryfunc)Dummy_sub,                         /*nb_subtract*/
     (binaryfunc)Dummy_multiply,                    /*nb_multiply*/
-    INITIALIZE_NB_DIVIDE_ZERO   /*nb_divide*/
     0,                                              /*nb_remainder*/
     0,                                              /*nb_divmod*/
     0,                                              /*nb_power*/
@@ -255,16 +254,12 @@ static PyNumberMethods Dummy_as_number =
     0,                                              /*nb_and*/
     0,                                              /*nb_xor*/
     0,                                              /*nb_or*/
-    INITIALIZE_NB_COERCE_ZERO                       /*nb_coerce*/
     0,                                              /*nb_int*/
     0,                                              /*nb_long*/
     0,                                              /*nb_float*/
-    INITIALIZE_NB_OCT_ZERO                          /*nb_oct*/
-    INITIALIZE_NB_HEX_ZERO                          /*nb_hex*/
     (binaryfunc)Dummy_inplace_add,                 /*inplace_add*/
     (binaryfunc)Dummy_inplace_sub,                 /*inplace_subtract*/
     (binaryfunc)Dummy_inplace_multiply,            /*inplace_multiply*/
-    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO               /*inplace_divide*/
     0,                                              /*inplace_remainder*/
     0,                                              /*inplace_power*/
     0,                                              /*inplace_lshift*/
@@ -300,7 +295,7 @@ PyTypeObject DummyType =
     0,                                              /*tp_getattro*/
     0,                                              /*tp_setattro*/
     0,                                              /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC, /*tp_flags*/
     "Dummy objects.",                               /* tp_doc */
     (traverseproc)Dummy_traverse,                  /* tp_traverse */
     (inquiry)Dummy_clear,                          /* tp_clear */
@@ -435,7 +430,6 @@ TriggerDummy_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     TriggerDummy *self;
     self = (TriggerDummy *)type->tp_alloc(type, 0);
 
-    self->input = PyFloat_FromDouble(0);
     self->modebuffer[0] = 0;
     self->modebuffer[1] = 0;
 
@@ -502,7 +496,6 @@ static PyNumberMethods TriggerDummy_as_number =
     (binaryfunc)TriggerDummy_add,                         /*nb_add*/
     (binaryfunc)TriggerDummy_sub,                         /*nb_subtract*/
     (binaryfunc)TriggerDummy_multiply,                    /*nb_multiply*/
-    INITIALIZE_NB_DIVIDE_ZERO                       /*nb_divide*/
     0,                                              /*nb_remainder*/
     0,                                              /*nb_divmod*/
     0,                                              /*nb_power*/
@@ -516,16 +509,12 @@ static PyNumberMethods TriggerDummy_as_number =
     0,                                              /*nb_and*/
     0,                                              /*nb_xor*/
     0,                                              /*nb_or*/
-    INITIALIZE_NB_COERCE_ZERO                       /*nb_coerce*/
     0,                                              /*nb_int*/
     0,                                              /*nb_long*/
     0,                                              /*nb_float*/
-    INITIALIZE_NB_OCT_ZERO                          /*nb_oct*/
-    INITIALIZE_NB_HEX_ZERO                          /*nb_hex*/
     (binaryfunc)TriggerDummy_inplace_add,                 /*inplace_add*/
     (binaryfunc)TriggerDummy_inplace_sub,                 /*inplace_subtract*/
     (binaryfunc)TriggerDummy_inplace_multiply,            /*inplace_multiply*/
-    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO                                           /*inplace_divide*/
     0,                                              /*inplace_remainder*/
     0,                                              /*inplace_power*/
     0,                                              /*inplace_lshift*/
@@ -561,7 +550,7 @@ PyTypeObject TriggerDummyType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES,  /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC,  /*tp_flags*/
     "TriggerDummy objects. Sends trigger at the end of playback.",           /* tp_doc */
     (traverseproc)TriggerDummy_traverse,   /* tp_traverse */
     (inquiry)TriggerDummy_clear,           /* tp_clear */
