@@ -19,7 +19,6 @@
  *************************************************************************/
 
 #include <Python.h>
-#include "py2to3.h"
 #include "structmember.h"
 #include <math.h>
 #include "pyomodule.h"
@@ -740,31 +739,26 @@ Freeverb_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (sizetmp)
     {
         PyObject_CallMethod((PyObject *)self, "setSize", "O", sizetmp);
-        Py_DECREF(sizetmp);
     }
 
     if (damptmp)
     {
         PyObject_CallMethod((PyObject *)self, "setDamp", "O", damptmp);
-        Py_DECREF(damptmp);
     }
 
     if (mixtmp)
     {
         PyObject_CallMethod((PyObject *)self, "setMix", "O", mixtmp);
-        Py_DECREF(mixtmp);
     }
 
     if (multmp)
     {
         PyObject_CallMethod((PyObject *)self, "setMul", "O", multmp);
-        Py_DECREF(multmp);
     }
 
     if (addtmp)
     {
         PyObject_CallMethod((PyObject *)self, "setAdd", "O", addtmp);
-        Py_DECREF(addtmp);
     }
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
@@ -825,6 +819,10 @@ static PyObject * Freeverb_inplace_sub(Freeverb *self, PyObject *arg) { INPLACE_
 static PyObject * Freeverb_div(Freeverb *self, PyObject *arg) { DIV };
 static PyObject * Freeverb_inplace_div(Freeverb *self, PyObject *arg) { INPLACE_DIV };
 
+static PyObject * Freeverb_setSize(Freeverb *self, PyObject *arg) { SET_PARAM(self->size, self->size_stream, 2); }
+static PyObject * Freeverb_setDamp(Freeverb *self, PyObject *arg) { SET_PARAM(self->damp, self->damp_stream, 3); }
+static PyObject * Freeverb_setMix(Freeverb *self, PyObject *arg) {SET_PARAM(self->mix, self->mix_stream, 4); }
+
 static PyObject *
 Freeverb_reset(Freeverb *self)
 {
@@ -854,107 +852,6 @@ Freeverb_reset(Freeverb *self)
     Py_RETURN_NONE;
 }
 
-static PyObject *
-Freeverb_setSize(Freeverb *self, PyObject *arg)
-{
-    PyObject *tmp, *streamtmp;
-
-    ASSERT_ARG_NOT_NULL
-
-    int isNumber = PyNumber_Check(arg);
-
-    tmp = arg;
-    Py_INCREF(tmp);
-    Py_DECREF(self->size);
-
-    if (isNumber == 1)
-    {
-        self->size = PyNumber_Float(tmp);
-        self->modebuffer[2] = 0;
-    }
-    else
-    {
-        self->size = tmp;
-        Py_INCREF(self->size);
-        streamtmp = PyObject_CallMethod((PyObject *)self->size, "_getStream", NULL);
-        Py_INCREF(streamtmp);
-        Py_XDECREF(self->size_stream);
-        self->size_stream = (Stream *)streamtmp;
-        self->modebuffer[2] = 1;
-    }
-
-    (*self->mode_func_ptr)(self);
-
-    Py_RETURN_NONE;
-}
-
-static PyObject *
-Freeverb_setDamp(Freeverb *self, PyObject *arg)
-{
-    PyObject *tmp, *streamtmp;
-
-    ASSERT_ARG_NOT_NULL
-
-    int isNumber = PyNumber_Check(arg);
-
-    tmp = arg;
-    Py_INCREF(tmp);
-    Py_DECREF(self->damp);
-
-    if (isNumber == 1)
-    {
-        self->damp = PyNumber_Float(tmp);
-        self->modebuffer[3] = 0;
-    }
-    else
-    {
-        self->damp = tmp;
-        Py_INCREF(self->damp);
-        streamtmp = PyObject_CallMethod((PyObject *)self->damp, "_getStream", NULL);
-        Py_INCREF(streamtmp);
-        Py_XDECREF(self->damp_stream);
-        self->damp_stream = (Stream *)streamtmp;
-        self->modebuffer[3] = 1;
-    }
-
-    (*self->mode_func_ptr)(self);
-
-    Py_RETURN_NONE;
-}
-
-static PyObject *
-Freeverb_setMix(Freeverb *self, PyObject *arg)
-{
-    PyObject *tmp, *streamtmp;
-
-    ASSERT_ARG_NOT_NULL
-
-    int isNumber = PyNumber_Check(arg);
-
-    tmp = arg;
-    Py_INCREF(tmp);
-    Py_DECREF(self->mix);
-
-    if (isNumber == 1)
-    {
-        self->mix = PyNumber_Float(tmp);
-        self->modebuffer[4] = 0;
-    }
-    else
-    {
-        self->mix = tmp;
-        Py_INCREF(self->mix);
-        streamtmp = PyObject_CallMethod((PyObject *)self->mix, "_getStream", NULL);
-        Py_INCREF(streamtmp);
-        Py_XDECREF(self->mix_stream);
-        self->mix_stream = (Stream *)streamtmp;
-        self->modebuffer[4] = 1;
-    }
-
-    (*self->mode_func_ptr)(self);
-
-    Py_RETURN_NONE;
-}
 static PyMemberDef Freeverb_members[] =
 {
     {"server", T_OBJECT_EX, offsetof(Freeverb, server), 0, "Pyo server."},
@@ -991,7 +888,6 @@ static PyNumberMethods Freeverb_as_number =
     (binaryfunc)Freeverb_add,                      /*nb_add*/
     (binaryfunc)Freeverb_sub,                 /*nb_subtract*/
     (binaryfunc)Freeverb_multiply,                 /*nb_multiply*/
-    INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
     0,                /*nb_remainder*/
     0,                   /*nb_divmod*/
     0,                   /*nb_power*/
@@ -1005,16 +901,12 @@ static PyNumberMethods Freeverb_as_number =
     0,              /*nb_and*/
     0,              /*nb_xor*/
     0,               /*nb_or*/
-    INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
     0,                       /*nb_int*/
     0,                      /*nb_long*/
     0,                     /*nb_float*/
-    INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
-    INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
     (binaryfunc)Freeverb_inplace_add,              /*inplace_add*/
     (binaryfunc)Freeverb_inplace_sub,         /*inplace_subtract*/
     (binaryfunc)Freeverb_inplace_multiply,         /*inplace_multiply*/
-    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
     0,        /*inplace_remainder*/
     0,           /*inplace_power*/
     0,       /*inplace_lshift*/
@@ -1050,7 +942,7 @@ PyTypeObject FreeverbType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC, /*tp_flags*/
     "Freeverb objects. Jezar's Freeverb .",           /* tp_doc */
     (traverseproc)Freeverb_traverse,   /* tp_traverse */
     (inquiry)Freeverb_clear,           /* tp_clear */
