@@ -19,7 +19,6 @@
  *************************************************************************/
 
 #include <Python.h>
-#include "py2to3.h"
 #include "structmember.h"
 #include "pyomodule.h"
 #include "servermodule.h"
@@ -403,13 +402,13 @@ NewMatrix_setMatrix(NewMatrix *self, PyObject *value)
     if (value == NULL)
     {
         PyErr_SetString(PyExc_TypeError, "Cannot delete the list attribute.");
-        return PyInt_FromLong(-1);
+        return PyLong_FromLong(-1);
     }
 
     if (! PyList_Check(value))
     {
         PyErr_SetString(PyExc_TypeError, "The matrix value value must be a list.");
-        return PyInt_FromLong(-1);
+        return PyLong_FromLong(-1);
     }
 
     int height = PyList_Size(value);
@@ -418,7 +417,7 @@ NewMatrix_setMatrix(NewMatrix *self, PyObject *value)
     if (height != self->height || width != self->width)
     {
         PyErr_SetString(PyExc_TypeError, "New matrix must be of the same size as actual matrix.");
-        return PyInt_FromLong(-1);
+        return PyLong_FromLong(-1);
     }
 
     for (i = 0; i < self->height; i++)
@@ -444,7 +443,7 @@ NewMatrix_genSineTerrain(NewMatrix *self, PyObject *args, PyObject *kwds)
     static char *kwlist[] = {"freq", "phase", NULL};
 
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE__FF, kwlist, &freq, &phase))
-        return PyInt_FromLong(-1);
+        return PyLong_FromLong(-1);
 
     xfreq = TWOPI * freq;
     xsize = 1.0 / self->width;
@@ -676,9 +675,8 @@ MatrixRec_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
     INIT_INPUT_STREAM
 
-    Py_XDECREF(self->matrix);
-    Py_INCREF(matrixtmp);
     self->matrix = (NewMatrix *)matrixtmp;
+    Py_INCREF(self->matrix);
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
 
@@ -721,14 +719,11 @@ static PyObject * MatrixRec_stop(MatrixRec *self, PyObject *args, PyObject *kwds
 static PyObject *
 MatrixRec_setMatrix(MatrixRec *self, PyObject *arg)
 {
-    PyObject *tmp;
-
     ASSERT_ARG_NOT_NULL
 
-    tmp = arg;
-    Py_INCREF(tmp);
     Py_DECREF(self->matrix);
-    self->matrix = (NewMatrix *)tmp;
+    self->matrix = (NewMatrix *)arg;
+    Py_INCREF(self->matrix);
 
     Py_RETURN_NONE;
 }
@@ -775,7 +770,7 @@ PyTypeObject MatrixRecType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC, /*tp_flags*/
     "MatrixRec objects. Record audio input in a Matrix object.",           /* tp_doc */
     (traverseproc)MatrixRec_traverse,   /* tp_traverse */
     (inquiry)MatrixRec_clear,           /* tp_clear */
@@ -887,9 +882,8 @@ MatrixRecLoop_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
     INIT_INPUT_STREAM
 
-    Py_XDECREF(self->matrix);
-    Py_INCREF(matrixtmp);
     self->matrix = (NewMatrix *)matrixtmp;
+    Py_INCREF(self->matrix);
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
 
@@ -916,14 +910,11 @@ static PyObject * MatrixRecLoop_stop(MatrixRecLoop *self, PyObject *args, PyObje
 static PyObject *
 MatrixRecLoop_setMatrix(MatrixRecLoop *self, PyObject *arg)
 {
-    PyObject *tmp;
-
     ASSERT_ARG_NOT_NULL
 
-    tmp = arg;
-    Py_INCREF(tmp);
     Py_DECREF(self->matrix);
-    self->matrix = (NewMatrix *)tmp;
+    self->matrix = (NewMatrix *)arg;
+    Py_INCREF(self->matrix);
 
     Py_RETURN_NONE;
 }
@@ -970,7 +961,7 @@ PyTypeObject MatrixRecLoopType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC, /*tp_flags*/
     "MatrixRecLoop objects. Record circular audio input in a Matrix object.",           /* tp_doc */
     (traverseproc)MatrixRecLoop_traverse,   /* tp_traverse */
     (inquiry)MatrixRecLoop_clear,           /* tp_clear */
@@ -1102,18 +1093,16 @@ MatrixMorph_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
     INIT_INPUT_STREAM
 
-    Py_XDECREF(self->matrix);
-    Py_INCREF(matrixtmp);
     self->matrix = (PyObject *)matrixtmp;
+    Py_INCREF(self->matrix);
 
     width = NewMatrix_getWidth((NewMatrix *)self->matrix);
     height = NewMatrix_getHeight((NewMatrix *)self->matrix);
     numsamps = width * height;
     self->buffer = (MYFLT *)PyMem_RawRealloc(self->buffer, (numsamps) * sizeof(MYFLT));
 
-    Py_XDECREF(self->sources);
-    Py_INCREF(sourcestmp);
     self->sources = (PyObject *)sourcestmp;
+    Py_INCREF(self->sources);
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
 
@@ -1129,14 +1118,11 @@ static PyObject * MatrixMorph_stop(MatrixMorph *self, PyObject *args, PyObject *
 static PyObject *
 MatrixMorph_setMatrix(MatrixMorph *self, PyObject *arg)
 {
-    PyObject *tmp;
-
     ASSERT_ARG_NOT_NULL
 
-    tmp = arg;
-    Py_INCREF(tmp);
     Py_DECREF(self->matrix);
-    self->matrix = (PyObject *)tmp;
+    self->matrix = (PyObject *)arg;
+    Py_INCREF(self->matrix);
 
     Py_RETURN_NONE;
 }
@@ -1149,7 +1135,7 @@ MatrixMorph_setSources(MatrixMorph *self, PyObject *arg)
     if (! PyList_Check(arg))
     {
         PyErr_SetString(PyExc_TypeError, "The amplitude list attribute value must be a list.");
-        return PyInt_FromLong(-1);
+        return PyLong_FromLong(-1);
     }
 
     Py_INCREF(arg);
@@ -1201,7 +1187,7 @@ PyTypeObject MatrixMorphType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC, /*tp_flags*/
     "MatrixMorph objects. Interpolation contents of different matrix objects.",           /* tp_doc */
     (traverseproc)MatrixMorph_traverse,   /* tp_traverse */
     (inquiry)MatrixMorph_clear,           /* tp_clear */
