@@ -19,7 +19,6 @@
  *************************************************************************/
 
 #include <Python.h>
-#include "py2to3.h"
 #include "structmember.h"
 #include "pyomodule.h"
 #include "streammodule.h"
@@ -157,6 +156,9 @@ MatrixPointer_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     MatrixPointer *self;
     self = (MatrixPointer *)type->tp_alloc(type, 0);
 
+    self->x = PyFloat_FromDouble(0.0);
+    self->y = PyFloat_FromDouble(0.0);
+
     self->modebuffer[0] = 0;
     self->modebuffer[1] = 0;
 
@@ -175,7 +177,6 @@ MatrixPointer_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
         Py_RETURN_NONE;
     }
 
-    Py_XDECREF(self->matrix);
     self->matrix = PyObject_CallMethod((PyObject *)matrixtmp, "getMatrixStream", "");
 
     if (xtmp)
@@ -191,13 +192,11 @@ MatrixPointer_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (multmp)
     {
         PyObject_CallMethod((PyObject *)self, "setMul", "O", multmp);
-        Py_DECREF(multmp);
     }
 
     if (addtmp)
     {
         PyObject_CallMethod((PyObject *)self, "setAdd", "O", addtmp);
-        Py_DECREF(addtmp);
     }
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
@@ -235,20 +234,16 @@ MatrixPointer_getMatrix(MatrixPointer* self)
 static PyObject *
 MatrixPointer_setMatrix(MatrixPointer *self, PyObject *arg)
 {
-    PyObject *tmp;
-
     ASSERT_ARG_NOT_NULL
 
-    tmp = arg;
-
-    if ( PyObject_HasAttrString((PyObject *)tmp, "getMatrixStream") == 0 )
+    if ( PyObject_HasAttrString((PyObject *)arg, "getMatrixStream") == 0 )
     {
         PyErr_SetString(PyExc_TypeError, "\"matrix\" argument of MatrixPointer must be a PyoMatrixObject.\n");
         Py_RETURN_NONE;
     }
 
     Py_DECREF(self->matrix);
-    self->matrix = PyObject_CallMethod((PyObject *)tmp, "getMatrixStream", "");
+    self->matrix = PyObject_CallMethod((PyObject *)arg, "getMatrixStream", "");
 
     Py_RETURN_NONE;
 }
@@ -256,26 +251,21 @@ MatrixPointer_setMatrix(MatrixPointer *self, PyObject *arg)
 static PyObject *
 MatrixPointer_setX(MatrixPointer *self, PyObject *arg)
 {
-    PyObject *tmp, *streamtmp;
-
     ASSERT_ARG_NOT_NULL
 
-    tmp = arg;
-
-    if (PyObject_HasAttrString((PyObject *)tmp, "server") == 0)
+    if (PyObject_HasAttrString((PyObject *)arg, "server") == 0)
     {
         PyErr_SetString(PyExc_TypeError, "\"x\" attribute of MatrixPointer must be a PyoObject.\n");
         Py_RETURN_NONE;
     }
 
-    Py_INCREF(tmp);
-    Py_XDECREF(self->x);
+    Py_DECREF(self->x);
 
-    self->x = tmp;
-    streamtmp = PyObject_CallMethod((PyObject *)self->x, "_getStream", NULL);
-    Py_INCREF(streamtmp);
-    Py_XDECREF(self->x_stream);
+    self->x = arg;
+    Py_INCREF(self->x);
+    PyObject *streamtmp = PyObject_CallMethod((PyObject *)self->x, "_getStream", NULL);
     self->x_stream = (Stream *)streamtmp;
+    Py_INCREF(self->x_stream);
 
     Py_RETURN_NONE;
 }
@@ -283,26 +273,21 @@ MatrixPointer_setX(MatrixPointer *self, PyObject *arg)
 static PyObject *
 MatrixPointer_setY(MatrixPointer *self, PyObject *arg)
 {
-    PyObject *tmp, *streamtmp;
-
     ASSERT_ARG_NOT_NULL
 
-    tmp = arg;
-
-    if (PyObject_HasAttrString((PyObject *)tmp, "server") == 0)
+    if (PyObject_HasAttrString((PyObject *)arg, "server") == 0)
     {
         PyErr_SetString(PyExc_TypeError, "\"y\" attribute of MatrixPointer must be a PyoObject.\n");
         Py_RETURN_NONE;
     }
 
-    Py_INCREF(tmp);
-    Py_XDECREF(self->y);
+    Py_DECREF(self->y);
 
-    self->y = tmp;
-    streamtmp = PyObject_CallMethod((PyObject *)self->y, "_getStream", NULL);
-    Py_INCREF(streamtmp);
-    Py_XDECREF(self->y_stream);
+    self->y = arg;
+    Py_INCREF(self->y);
+    PyObject *streamtmp = PyObject_CallMethod((PyObject *)self->y, "_getStream", NULL);
     self->y_stream = (Stream *)streamtmp;
+    Py_INCREF(self->y_stream);
 
     Py_RETURN_NONE;
 }
@@ -342,7 +327,6 @@ static PyNumberMethods MatrixPointer_as_number =
     (binaryfunc)MatrixPointer_add,                      /*nb_add*/
     (binaryfunc)MatrixPointer_sub,                 /*nb_subtract*/
     (binaryfunc)MatrixPointer_multiply,                 /*nb_multiply*/
-    INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
     0,                /*nb_remainder*/
     0,                   /*nb_divmod*/
     0,                   /*nb_power*/
@@ -356,16 +340,12 @@ static PyNumberMethods MatrixPointer_as_number =
     0,              /*nb_and*/
     0,              /*nb_xor*/
     0,               /*nb_or*/
-    INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
     0,                       /*nb_int*/
     0,                      /*nb_long*/
     0,                     /*nb_float*/
-    INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
-    INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
     (binaryfunc)MatrixPointer_inplace_add,              /*inplace_add*/
     (binaryfunc)MatrixPointer_inplace_sub,         /*inplace_subtract*/
     (binaryfunc)MatrixPointer_inplace_multiply,         /*inplace_multiply*/
-    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
     0,        /*inplace_remainder*/
     0,           /*inplace_power*/
     0,       /*inplace_lshift*/
@@ -401,7 +381,7 @@ PyTypeObject MatrixPointerType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC, /*tp_flags*/
     "MatrixPointer objects. Read a waveform matrix with a pointer x.",           /* tp_doc */
     (traverseproc)MatrixPointer_traverse,   /* tp_traverse */
     (inquiry)MatrixPointer_clear,           /* tp_clear */
