@@ -19,7 +19,6 @@
  *************************************************************************/
 
 #include <Python.h>
-#include "py2to3.h"
 #include "structmember.h"
 #include <math.h>
 #include "pyomodule.h"
@@ -57,9 +56,7 @@ int OscReceiver_handler(const char *path, const char *types, lo_arg **argv, int
 
 MYFLT OscReceiver_getValue(OscReceiver *self, PyObject *path)
 {
-    PyObject *tmp;
-    tmp = PyDict_GetItem(self->dict, path);
-    return PyFloat_AsDouble(tmp);
+    return PyFloat_AsDouble(PyDict_GetItem(self->dict, path));
 }
 
 static void
@@ -118,9 +115,8 @@ OscReceiver_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
     if (PyList_Check(pathtmp))
     {
-        Py_INCREF(pathtmp);
-        Py_XDECREF(self->address_path);
         self->address_path = pathtmp;
+        Py_INCREF(self->address_path);
     }
     else
     {
@@ -151,7 +147,7 @@ OscReceiver_addAddress(OscReceiver *self, PyObject *arg)
 {
     int i;
 
-    if (PY_STRING_CHECK(arg))
+    if (PyUnicode_Check(arg))
     {
         PyObject *zero = PyFloat_FromDouble(0.);
         PyDict_SetItem(self->dict, arg, zero);
@@ -177,7 +173,7 @@ OscReceiver_delAddress(OscReceiver *self, PyObject *arg)
 {
     int i;
 
-    if (PY_STRING_CHECK(arg))
+    if (PyUnicode_Check(arg))
     {
         PyDict_DelItem(self->dict, arg);
     }
@@ -254,7 +250,7 @@ PyTypeObject OscReceiverType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC, /*tp_flags*/
     "OscReceiver objects. Receive values via Open Sound Control protocol.",           /* tp_doc */
     (traverseproc)OscReceiver_traverse,   /* tp_traverse */
     (inquiry)OscReceiver_clear,           /* tp_clear */
@@ -419,33 +415,29 @@ OscReceive_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "OO|OO", kwlist, &inputtmp, &pathtmp, &multmp, &addtmp))
         Py_RETURN_NONE;
 
-    Py_XDECREF(self->input);
-    Py_INCREF(inputtmp);
     self->input = inputtmp;
+    Py_INCREF(self->input);
 
     if (multmp)
     {
         PyObject_CallMethod((PyObject *)self, "setMul", "O", multmp);
-        Py_DECREF(multmp);
     }
 
     if (addtmp)
     {
         PyObject_CallMethod((PyObject *)self, "setAdd", "O", addtmp);
-        Py_DECREF(addtmp);
     }
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
 
-    if (!PY_STRING_CHECK(pathtmp))
+    if (!PyUnicode_Check(pathtmp))
     {
         PyErr_SetString(PyExc_TypeError, "The address attributes must be a string or a unicode.");
         Py_RETURN_NONE;
     }
 
-    Py_INCREF(pathtmp);
-    Py_XDECREF(self->address_path);
     self->address_path = pathtmp;
+    Py_INCREF(self->address_path);
 
     (*self->mode_func_ptr)(self);
 
@@ -457,7 +449,7 @@ OscReceive_setInterpolation(OscReceive *self, PyObject *arg)
 {
     ASSERT_ARG_NOT_NULL
 
-    self->interpolation = PyInt_AsLong(arg);
+    self->interpolation = PyLong_AsLong(arg);
 
     Py_RETURN_NONE;
 }
@@ -509,7 +501,6 @@ static PyNumberMethods OscReceive_as_number =
     (binaryfunc)OscReceive_add,                      /*nb_add*/
     (binaryfunc)OscReceive_sub,                 /*nb_subtract*/
     (binaryfunc)OscReceive_multiply,                 /*nb_multiply*/
-    INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
     0,                /*nb_remainder*/
     0,                   /*nb_divmod*/
     0,                   /*nb_power*/
@@ -523,16 +514,12 @@ static PyNumberMethods OscReceive_as_number =
     0,              /*nb_and*/
     0,              /*nb_xor*/
     0,               /*nb_or*/
-    INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
     0,                       /*nb_int*/
     0,                      /*nb_long*/
     0,                     /*nb_float*/
-    INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
-    INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
     (binaryfunc)OscReceive_inplace_add,              /*inplace_add*/
     (binaryfunc)OscReceive_inplace_sub,         /*inplace_subtract*/
     (binaryfunc)OscReceive_inplace_multiply,         /*inplace_multiply*/
-    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
     0,        /*inplace_remainder*/
     0,           /*inplace_power*/
     0,       /*inplace_lshift*/
@@ -568,7 +555,7 @@ PyTypeObject OscReceiveType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC, /*tp_flags*/
     "OscReceive objects. Receive values via Open Sound Control protocol.",           /* tp_doc */
     (traverseproc)OscReceive_traverse,   /* tp_traverse */
     (inquiry)OscReceive_clear,           /* tp_clear */
@@ -618,7 +605,7 @@ OscSend_compute_next_data_frame(OscSend *self)
         if (PyBytes_Check(self->address_path))
             path = PyBytes_AsString(self->address_path);
         else
-            path = PY_UNICODE_AS_UNICODE(self->address_path);
+            path = PyUnicode_AsUTF8(self->address_path);
 
         if (lo_send(self->address, path, "f", value) == -1)
         {
@@ -681,7 +668,7 @@ OscSend_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
 
-    if (!PY_STRING_CHECK(pathtmp))
+    if (!PyUnicode_Check(pathtmp))
     {
         PyErr_SetString(PyExc_TypeError, "The address attributes must be a string or a unicode (bytes or string in Python 3).");
         Py_RETURN_NONE;
@@ -703,7 +690,7 @@ OscSend_setBufferRate(OscSend *self, PyObject *arg)
 {
     ASSERT_ARG_NOT_NULL
 
-    self->bufrate = PyInt_AsLong(arg);
+    self->bufrate = PyLong_AsLong(arg);
 
     if (self->bufrate < 1)
         self->bufrate = 1;
@@ -756,7 +743,7 @@ PyTypeObject OscSendType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC, /*tp_flags*/
     "OscSend objects. Send values via Open Sound Control protocol.",           /* tp_doc */
     (traverseproc)OscSend_traverse,   /* tp_traverse */
     (inquiry)OscSend_clear,           /* tp_clear */
@@ -809,7 +796,7 @@ OscDataSend_compute_next_data_frame(OscDataSend *self)
         if (PyBytes_Check(self->address_path))
             path = PyBytes_AsString(self->address_path);
         else
-            path = PY_UNICODE_AS_UNICODE(self->address_path);
+            path = PyUnicode_AsUTF8(self->address_path);
 
         msg = lo_message_new();
 
@@ -821,7 +808,7 @@ OscDataSend_compute_next_data_frame(OscDataSend *self)
             switch (self->types[i])
             {
                 case LO_INT32:
-                    lo_message_add_int32(msg, PyInt_AS_LONG(PyList_GET_ITEM(inlist, i)));
+                    lo_message_add_int32(msg, PyLong_AsLong(PyList_GET_ITEM(inlist, i)));
                     break;
 
                 case LO_INT64:
@@ -837,11 +824,11 @@ OscDataSend_compute_next_data_frame(OscDataSend *self)
                     break;
 
                 case LO_STRING:
-                    lo_message_add_string(msg, PY_STRING_AS_STRING(PyList_GET_ITEM(inlist, i)));
+                    lo_message_add_string(msg, PyUnicode_AsUTF8(PyList_GET_ITEM(inlist, i)));
                     break;
 
                 case LO_CHAR:
-                    lo_message_add_char(msg, (char)PY_STRING_AS_STRING(PyList_GET_ITEM(inlist, i))[0]);
+                    lo_message_add_char(msg, (char)PyUnicode_AsUTF8(PyList_GET_ITEM(inlist, i))[0]);
                     break;
 
                 case LO_BLOB:
@@ -851,7 +838,7 @@ OscDataSend_compute_next_data_frame(OscDataSend *self)
 
                     for (j = 0; j < blobsize; j++)
                     {
-                        blobdata[j] = (char)PY_STRING_AS_STRING(PyList_GET_ITEM(datalist, j))[0];
+                        blobdata[j] = (char)PyUnicode_AsUTF8(PyList_GET_ITEM(datalist, j))[0];
                     }
 
                     blob = lo_blob_new(blobsize * sizeof(char), blobdata);
@@ -863,7 +850,7 @@ OscDataSend_compute_next_data_frame(OscDataSend *self)
 
                     for (j = 0; j < 4; j++)
                     {
-                        midi[j] = (uint8_t)PyInt_AS_LONG(PyList_GET_ITEM(datalist, j));
+                        midi[j] = (uint8_t)PyLong_AsLong(PyList_GET_ITEM(datalist, j));
                     }
 
                     lo_message_add_midi(msg, midi);
@@ -954,7 +941,7 @@ OscDataSend_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
 
-    if (!PY_STRING_CHECK(pathtmp))
+    if (!PyUnicode_Check(pathtmp))
     {
         PyErr_SetString(PyExc_TypeError, "The address attributes must be of type string or unicode (bytes or string in Python 3).");
         Py_RETURN_NONE;
@@ -982,15 +969,12 @@ static PyObject * OscDataSend_stop(OscDataSend *self, PyObject *args, PyObject *
 static PyObject *
 OscDataSend_send(OscDataSend *self, PyObject *arg)
 {
-    PyObject *tmp;
-
     ASSERT_ARG_NOT_NULL
 
     if (PyList_Check(arg))
     {
-        tmp = arg;
-        Py_INCREF(tmp);
-        PyList_Append(self->value, tmp);
+        Py_INCREF(arg);
+        PyList_Append(self->value, arg);
         self->something_to_send++;
     }
     else
@@ -1037,7 +1021,7 @@ PyTypeObject OscDataSendType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC, /*tp_flags*/
     "OscDataSend objects. Send data values via Open Sound Control protocol.",           /* tp_doc */
     (traverseproc)OscDataSend_traverse,   /* tp_traverse */
     (inquiry)OscDataSend_clear,           /* tp_clear */
@@ -1095,7 +1079,7 @@ int OscDataReceive_handler(const char *path, const char *types, lo_arg **argv, i
         }
         else
         {
-            if (lo_pattern_match(path, PY_UNICODE_AS_UNICODE(PyList_GET_ITEM(self->address_path, i))))
+            if (lo_pattern_match(path, PyUnicode_AsUTF8(PyList_GET_ITEM(self->address_path, i))))
             {
                 ok = 1;
                 break;
@@ -1112,7 +1096,7 @@ int OscDataReceive_handler(const char *path, const char *types, lo_arg **argv, i
             switch (types[i])
             {
                 case LO_INT32:
-                    PyTuple_SET_ITEM(tup, i + 1, PyInt_FromLong(argv[i]->i));
+                    PyTuple_SET_ITEM(tup, i + 1, PyLong_FromLong(argv[i]->i));
                     break;
 
                 case LO_INT64:
@@ -1154,7 +1138,7 @@ int OscDataReceive_handler(const char *path, const char *types, lo_arg **argv, i
 
                     for (j = 0; j < 4; j++)
                     {
-                        PyList_SET_ITEM(charlist, j, PyInt_FromLong(argv[i]->m[j]));
+                        PyList_SET_ITEM(charlist, j, PyLong_FromLong(argv[i]->m[j]));
                     }
 
                     PyTuple_SET_ITEM(tup, i + 1, charlist);
@@ -1281,7 +1265,7 @@ OscDataReceive_addAddress(OscDataReceive *self, PyObject *arg)
 
     if (arg != NULL)
     {
-        if (PY_STRING_CHECK(arg))
+        if (PyUnicode_Check(arg))
             PyList_Append(self->address_path, arg);
         else if (PyList_Check(arg))
         {
@@ -1302,9 +1286,9 @@ OscDataReceive_delAddress(OscDataReceive *self, PyObject *arg)
 {
     if (arg != NULL)
     {
-        if (PyInt_Check(arg))
+        if (PyLong_Check(arg))
         {
-            PySequence_DelItem(self->address_path, PyInt_AsLong(arg));
+            PySequence_DelItem(self->address_path, PyLong_AsLong(arg));
         }
     }
 
@@ -1350,7 +1334,7 @@ PyTypeObject OscDataReceiveType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC, /*tp_flags*/
     "OscDataReceive objects. Receive values via Open Sound Control protocol.",           /* tp_doc */
     (traverseproc)OscDataReceive_traverse,   /* tp_traverse */
     (inquiry)OscDataReceive_clear,           /* tp_clear */
@@ -1408,9 +1392,9 @@ int OscListReceiver_handler(const char *path, const char *types, lo_arg **argv,
 PyObject *
 OscListReceiver_getValue(OscListReceiver *self, PyObject *path)
 {
-    PyObject *tmp;
-    tmp = PyDict_GetItem(self->dict, path);
-    return tmp;
+    PyObject *value = PyDict_GetItem(self->dict, path);
+    Py_INCREF(value);
+    return value;
 }
 
 static void
@@ -1515,7 +1499,7 @@ OscListReceiver_addAddress(OscListReceiver *self, PyObject *arg)
     PyObject *flist;
     int i, j;
 
-    if (PY_STRING_CHECK(arg))
+    if (PyUnicode_Check(arg))
     {
         flist = PyList_New(self->num);
 
@@ -1555,7 +1539,7 @@ OscListReceiver_delAddress(OscListReceiver *self, PyObject *arg)
 {
     int i;
 
-    if (PY_STRING_CHECK(arg))
+    if (PyUnicode_Check(arg))
     {
         PyDict_DelItem(self->dict, arg);
     }
@@ -1633,7 +1617,7 @@ PyTypeObject OscListReceiverType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC, /*tp_flags*/
     "OscListReceiver objects. Receive list of values via Open Sound Control protocol.",           /* tp_doc */
     (traverseproc)OscListReceiver_traverse,   /* tp_traverse */
     (inquiry)OscListReceiver_clear,           /* tp_clear */
@@ -1802,33 +1786,29 @@ OscListReceive_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "OOi|OO", kwlist, &inputtmp, &pathtmp, &self->order, &multmp, &addtmp))
         Py_RETURN_NONE;
 
-    Py_XDECREF(self->input);
-    Py_INCREF(inputtmp);
     self->input = inputtmp;
+    Py_INCREF(self->input);
 
     if (multmp)
     {
         PyObject_CallMethod((PyObject *)self, "setMul", "O", multmp);
-        Py_DECREF(multmp);
     }
 
     if (addtmp)
     {
         PyObject_CallMethod((PyObject *)self, "setAdd", "O", addtmp);
-        Py_DECREF(addtmp);
     }
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
 
-    if (!PY_STRING_CHECK(pathtmp))
+    if (!PyUnicode_Check(pathtmp))
     {
         PyErr_SetString(PyExc_TypeError, "OscListReceive: the address attributes must be a string or a unicode.");
         Py_RETURN_NONE;
     }
 
-    Py_INCREF(pathtmp);
-    Py_XDECREF(self->address_path);
     self->address_path = pathtmp;
+    Py_INCREF(self->address_path);
 
     (*self->mode_func_ptr)(self);
 
@@ -1840,7 +1820,7 @@ OscListReceive_setInterpolation(OscListReceive *self, PyObject *arg)
 {
     ASSERT_ARG_NOT_NULL
 
-    self->interpolation = PyInt_AsLong(arg);
+    self->interpolation = PyLong_AsLong(arg);
 
     Py_RETURN_NONE;
 }
@@ -1892,7 +1872,6 @@ static PyNumberMethods OscListReceive_as_number =
     (binaryfunc)OscListReceive_add,                      /*nb_add*/
     (binaryfunc)OscListReceive_sub,                 /*nb_subtract*/
     (binaryfunc)OscListReceive_multiply,                 /*nb_multiply*/
-    INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
     0,                /*nb_remainder*/
     0,                   /*nb_divmod*/
     0,                   /*nb_power*/
@@ -1906,16 +1885,12 @@ static PyNumberMethods OscListReceive_as_number =
     0,              /*nb_and*/
     0,              /*nb_xor*/
     0,               /*nb_or*/
-    INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
     0,                       /*nb_int*/
     0,                      /*nb_long*/
     0,                     /*nb_float*/
-    INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
-    INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
     (binaryfunc)OscListReceive_inplace_add,              /*inplace_add*/
     (binaryfunc)OscListReceive_inplace_sub,         /*inplace_subtract*/
     (binaryfunc)OscListReceive_inplace_multiply,         /*inplace_multiply*/
-    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
     0,        /*inplace_remainder*/
     0,           /*inplace_power*/
     0,       /*inplace_lshift*/
@@ -1951,7 +1926,7 @@ PyTypeObject OscListReceiveType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC, /*tp_flags*/
     "OscListReceive objects. Receive one value from a list of floats via Open Sound Control protocol.",           /* tp_doc */
     (traverseproc)OscListReceive_traverse,   /* tp_traverse */
     (inquiry)OscListReceive_clear,           /* tp_clear */
