@@ -18,8 +18,9 @@
  * License along with pyo.  If not, see <http://www.gnu.org/licenses/>.   *
  *************************************************************************/
 
+#define PY_SSIZE_T_CLEAN
+
 #include <Python.h>
-#include "py2to3.h"
 #include "structmember.h"
 #include <math.h>
 #include "pyomodule.h"
@@ -358,7 +359,6 @@ SfPlayer_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (speedtmp)
     {
         PyObject_CallMethod((PyObject *)self, "setSpeed", "O", speedtmp);
-        Py_DECREF(speedtmp);
     }
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
@@ -422,39 +422,7 @@ static PyObject * SfPlayer_out(SfPlayer *self, PyObject *args, PyObject *kwds)
 
 static PyObject * SfPlayer_stop(SfPlayer *self, PyObject *args, PyObject *kwds) { STOP };
 
-static PyObject *
-SfPlayer_setSpeed(SfPlayer *self, PyObject *arg)
-{
-    PyObject *tmp, *streamtmp;
-
-    ASSERT_ARG_NOT_NULL
-
-    int isNumber = PyNumber_Check(arg);
-
-    tmp = arg;
-    Py_INCREF(tmp);
-    Py_DECREF(self->speed);
-
-    if (isNumber == 1)
-    {
-        self->speed = PyNumber_Float(tmp);
-        self->modebuffer[0] = 0;
-    }
-    else
-    {
-        self->speed = tmp;
-        Py_INCREF(self->speed);
-        streamtmp = PyObject_CallMethod((PyObject *)self->speed, "_getStream", NULL);
-        Py_INCREF(streamtmp);
-        Py_XDECREF(self->speed_stream);
-        self->speed_stream = (Stream *)streamtmp;
-        self->modebuffer[0] = 1;
-    }
-
-    (*self->mode_func_ptr)(self);
-
-    Py_RETURN_NONE;
-}
+static PyObject * SfPlayer_setSpeed(SfPlayer *self, PyObject *arg) { SET_PARAM(self->speed, self->speed_stream, 0); }
 
 static PyObject *
 SfPlayer_setSound(SfPlayer *self, PyObject *args)
@@ -468,7 +436,7 @@ SfPlayer_setSound(SfPlayer *self, PyObject *args)
     if (! PyArg_ParseTuple(args, "s#", &self->path, &psize))
         Py_RETURN_NONE;
 
-    //self->path = PY_STRING_AS_STRING(arg);
+    //self->path = PyUnicode_AsUTF8(arg);
 
     sf_close(self->sf);
 
@@ -499,7 +467,7 @@ SfPlayer_setLoop(SfPlayer *self, PyObject *arg)
 {
     ASSERT_ARG_NOT_NULL
 
-    self->loop = PyInt_AsLong(arg);
+    self->loop = PyLong_AsLong(arg);
 
     Py_RETURN_NONE;
 }
@@ -509,9 +477,7 @@ SfPlayer_setOffset(SfPlayer *self, PyObject *arg)
 {
     ASSERT_ARG_NOT_NULL
 
-    int isNumber = PyNumber_Check(arg);
-
-    if (isNumber == 1)
+    if (PyNumber_Check(arg))
     {
         self->startPos = PyFloat_AsDouble(arg) * self->sr * self->srScale;
 
@@ -527,11 +493,9 @@ SfPlayer_setInterp(SfPlayer *self, PyObject *arg)
 {
     ASSERT_ARG_NOT_NULL
 
-    int isNumber = PyNumber_Check(arg);
-
-    if (isNumber == 1)
+    if (PyNumber_Check(arg))
     {
-        self->interp = PyInt_AsLong(PyNumber_Int(arg));
+        self->interp = PyLong_AsLong(PyNumber_Long(arg));
     }
 
     SET_INTERP_POINTER
@@ -591,7 +555,7 @@ PyTypeObject SfPlayerType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES,  /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC,  /*tp_flags*/
     "SfPlayer objects. Reads a soundfile directly from disk.",           /* tp_doc */
     (traverseproc)SfPlayer_traverse,   /* tp_traverse */
     (inquiry)SfPlayer_clear,           /* tp_clear */
@@ -741,20 +705,17 @@ SfPlay_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "O|iOO", kwlist, &maintmp, &self->chnl, &multmp, &addtmp))
         Py_RETURN_NONE;
 
-    Py_XDECREF(self->mainPlayer);
-    Py_INCREF(maintmp);
     self->mainPlayer = (SfPlayer *)maintmp;
+    Py_INCREF(self->mainPlayer);
 
     if (multmp)
     {
         PyObject_CallMethod((PyObject *)self, "setMul", "O", multmp);
-        Py_DECREF(multmp);
     }
 
     if (addtmp)
     {
         PyObject_CallMethod((PyObject *)self, "setAdd", "O", addtmp);
-        Py_DECREF(addtmp);
     }
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
@@ -812,7 +773,6 @@ static PyNumberMethods SfPlay_as_number =
     (binaryfunc)SfPlay_add,                      /*nb_add*/
     (binaryfunc)SfPlay_sub,                 /*nb_subtract*/
     (binaryfunc)SfPlay_multiply,                 /*nb_multiply*/
-    INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
     0,                /*nb_remainder*/
     0,                   /*nb_divmod*/
     0,                   /*nb_power*/
@@ -826,16 +786,12 @@ static PyNumberMethods SfPlay_as_number =
     0,              /*nb_and*/
     0,              /*nb_xor*/
     0,               /*nb_or*/
-    INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
     0,                       /*nb_int*/
     0,                      /*nb_long*/
     0,                     /*nb_float*/
-    INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
-    INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
     (binaryfunc)SfPlay_inplace_add,              /*inplace_add*/
     (binaryfunc)SfPlay_inplace_sub,         /*inplace_subtract*/
     (binaryfunc)SfPlay_inplace_multiply,         /*inplace_multiply*/
-    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
     0,        /*inplace_remainder*/
     0,           /*inplace_power*/
     0,       /*inplace_lshift*/
@@ -871,7 +827,7 @@ PyTypeObject SfPlayType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES,  /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC,  /*tp_flags*/
     "SfPlay objects. Reads a channel from a soundfile directly from disk.",           /* tp_doc */
     (traverseproc)SfPlay_traverse,   /* tp_traverse */
     (inquiry)SfPlay_clear,           /* tp_clear */
@@ -1385,7 +1341,6 @@ SfMarkerShuffler_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (speedtmp)
     {
         PyObject_CallMethod((PyObject *)self, "setSpeed", "O", speedtmp);
-        Py_DECREF(speedtmp);
     }
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
@@ -1438,50 +1393,16 @@ static PyObject * SfMarkerShuffler_play(SfMarkerShuffler *self, PyObject *args,
 static PyObject * SfMarkerShuffler_out(SfMarkerShuffler *self, PyObject *args, PyObject *kwds) { OUT };
 static PyObject * SfMarkerShuffler_stop(SfMarkerShuffler *self, PyObject *args, PyObject *kwds) { STOP };
 
-static PyObject *
-SfMarkerShuffler_setSpeed(SfMarkerShuffler *self, PyObject *arg)
-{
-    PyObject *tmp, *streamtmp;
-
-    ASSERT_ARG_NOT_NULL
-
-    int isNumber = PyNumber_Check(arg);
-
-    tmp = arg;
-    Py_INCREF(tmp);
-    Py_DECREF(self->speed);
-
-    if (isNumber == 1)
-    {
-        self->speed = PyNumber_Float(tmp);
-        self->modebuffer[0] = 0;
-    }
-    else
-    {
-        self->speed = tmp;
-        Py_INCREF(self->speed);
-        streamtmp = PyObject_CallMethod((PyObject *)self->speed, "_getStream", NULL);
-        Py_INCREF(streamtmp);
-        Py_XDECREF(self->speed_stream);
-        self->speed_stream = (Stream *)streamtmp;
-        self->modebuffer[0] = 1;
-    }
-
-    (*self->mode_func_ptr)(self);
-
-    Py_RETURN_NONE;
-}
+static PyObject * SfMarkerShuffler_setSpeed(SfMarkerShuffler *self, PyObject *arg) { SET_PARAM(self->speed, self->speed_stream, 0); }
 
 static PyObject *
 SfMarkerShuffler_setInterp(SfMarkerShuffler *self, PyObject *arg)
 {
     ASSERT_ARG_NOT_NULL
 
-    int isNumber = PyNumber_Check(arg);
-
-    if (isNumber == 1)
+    if (PyNumber_Check(arg))
     {
-        self->interp = PyInt_AsLong(PyNumber_Int(arg));
+        self->interp = PyLong_AsLong(PyNumber_Long(arg));
     }
 
     if (self->interp == 0)
@@ -1624,7 +1545,7 @@ PyTypeObject SfMarkerShufflerType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES,  /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC,  /*tp_flags*/
     "SfMarkerShuffler objects. Shuffle an AIFF soundfile from markers points.",           /* tp_doc */
     (traverseproc)SfMarkerShuffler_traverse,   /* tp_traverse */
     (inquiry)SfMarkerShuffler_clear,           /* tp_clear */
@@ -1774,20 +1695,17 @@ SfMarkerShuffle_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "O|iOO", kwlist, &maintmp, &self->chnl, &multmp, &addtmp))
         Py_RETURN_NONE;
 
-    Py_XDECREF(self->mainPlayer);
-    Py_INCREF(maintmp);
     self->mainPlayer = (SfMarkerShuffler *)maintmp;
+    Py_INCREF(self->mainPlayer);
 
     if (multmp)
     {
         PyObject_CallMethod((PyObject *)self, "setMul", "O", multmp);
-        Py_DECREF(multmp);
     }
 
     if (addtmp)
     {
         PyObject_CallMethod((PyObject *)self, "setAdd", "O", addtmp);
-        Py_DECREF(addtmp);
     }
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
@@ -1845,7 +1763,6 @@ static PyNumberMethods SfMarkerShuffle_as_number =
     (binaryfunc)SfMarkerShuffle_add,                      /*nb_add*/
     (binaryfunc)SfMarkerShuffle_sub,                 /*nb_subtract*/
     (binaryfunc)SfMarkerShuffle_multiply,                 /*nb_multiply*/
-    INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
     0,                /*nb_remainder*/
     0,                   /*nb_divmod*/
     0,                   /*nb_power*/
@@ -1859,16 +1776,12 @@ static PyNumberMethods SfMarkerShuffle_as_number =
     0,              /*nb_and*/
     0,              /*nb_xor*/
     0,               /*nb_or*/
-    INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
     0,                       /*nb_int*/
     0,                      /*nb_long*/
     0,                     /*nb_float*/
-    INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
-    INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
     (binaryfunc)SfMarkerShuffle_inplace_add,              /*inplace_add*/
     (binaryfunc)SfMarkerShuffle_inplace_sub,         /*inplace_subtract*/
     (binaryfunc)SfMarkerShuffle_inplace_multiply,         /*inplace_multiply*/
-    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
     0,        /*inplace_remainder*/
     0,           /*inplace_power*/
     0,       /*inplace_lshift*/
@@ -1904,7 +1817,7 @@ PyTypeObject SfMarkerShuffleType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES,  /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC,  /*tp_flags*/
     "SfMarkerShuffle objects. Reads a channel from a soundfile directly from disk.",           /* tp_doc */
     (traverseproc)SfMarkerShuffle_traverse,   /* tp_traverse */
     (inquiry)SfMarkerShuffle_clear,           /* tp_clear */
@@ -2296,13 +2209,11 @@ SfMarkerLooper_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (speedtmp)
     {
         PyObject_CallMethod((PyObject *)self, "setSpeed", "O", speedtmp);
-        Py_DECREF(speedtmp);
     }
 
     if (marktmp)
     {
         PyObject_CallMethod((PyObject *)self, "setMark", "O", marktmp);
-        Py_DECREF(marktmp);
     }
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
@@ -2353,80 +2264,17 @@ static PyObject * SfMarkerLooper_play(SfMarkerLooper *self, PyObject *args, PyOb
 static PyObject * SfMarkerLooper_out(SfMarkerLooper *self, PyObject *args, PyObject *kwds) { OUT };
 static PyObject * SfMarkerLooper_stop(SfMarkerLooper *self, PyObject *args, PyObject *kwds) { STOP };
 
-static PyObject *
-SfMarkerLooper_setSpeed(SfMarkerLooper *self, PyObject *arg)
-{
-    PyObject *tmp, *streamtmp;
-
-    ASSERT_ARG_NOT_NULL
-
-    int isNumber = PyNumber_Check(arg);
-
-    tmp = arg;
-    Py_INCREF(tmp);
-    Py_DECREF(self->speed);
-
-    if (isNumber == 1)
-    {
-        self->speed = PyNumber_Float(tmp);
-        self->modebuffer[0] = 0;
-    }
-    else
-    {
-        self->speed = tmp;
-        Py_INCREF(self->speed);
-        streamtmp = PyObject_CallMethod((PyObject *)self->speed, "_getStream", NULL);
-        Py_INCREF(streamtmp);
-        Py_XDECREF(self->speed_stream);
-        self->speed_stream = (Stream *)streamtmp;
-        self->modebuffer[0] = 1;
-    }
-
-    Py_RETURN_NONE;
-}
-
-static PyObject *
-SfMarkerLooper_setMark(SfMarkerLooper *self, PyObject *arg)
-{
-    PyObject *tmp, *streamtmp;
-
-    ASSERT_ARG_NOT_NULL
-
-    int isNumber = PyNumber_Check(arg);
-
-    tmp = arg;
-    Py_INCREF(tmp);
-    Py_DECREF(self->mark);
-
-    if (isNumber == 1)
-    {
-        self->mark = PyNumber_Float(tmp);
-        self->modebuffer[1] = 0;
-    }
-    else
-    {
-        self->mark = tmp;
-        Py_INCREF(self->mark);
-        streamtmp = PyObject_CallMethod((PyObject *)self->mark, "_getStream", NULL);
-        Py_INCREF(streamtmp);
-        Py_XDECREF(self->mark_stream);
-        self->mark_stream = (Stream *)streamtmp;
-        self->modebuffer[1] = 1;
-    }
-
-    Py_RETURN_NONE;
-}
+static PyObject * SfMarkerLooper_setSpeed(SfMarkerLooper *self, PyObject *arg) { SET_PARAM(self->speed, self->speed_stream, 0); }
+static PyObject * SfMarkerLooper_setMark(SfMarkerLooper *self, PyObject *arg) { SET_PARAM(self->mark, self->mark_stream, 1); }
 
 static PyObject *
 SfMarkerLooper_setInterp(SfMarkerLooper *self, PyObject *arg)
 {
     ASSERT_ARG_NOT_NULL
 
-    int isNumber = PyNumber_Check(arg);
-
-    if (isNumber == 1)
+    if (PyNumber_Check(arg))
     {
-        self->interp = PyInt_AsLong(PyNumber_Int(arg));
+        self->interp = PyLong_AsLong(PyNumber_Long(arg));
     }
 
     if (self->interp == 0)
@@ -2493,7 +2341,7 @@ PyTypeObject SfMarkerLooperType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES,  /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC,  /*tp_flags*/
     "SfMarkerLooper objects. Shuffle an AIFF soundfile from markers points.",           /* tp_doc */
     (traverseproc)SfMarkerLooper_traverse,   /* tp_traverse */
     (inquiry)SfMarkerLooper_clear,           /* tp_clear */
@@ -2643,20 +2491,17 @@ SfMarkerLoop_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "O|iOO", kwlist, &maintmp, &self->chnl, &multmp, &addtmp))
         Py_RETURN_NONE;
 
-    Py_XDECREF(self->mainPlayer);
-    Py_INCREF(maintmp);
     self->mainPlayer = (SfMarkerLooper *)maintmp;
+    Py_INCREF(self->mainPlayer);
 
     if (multmp)
     {
         PyObject_CallMethod((PyObject *)self, "setMul", "O", multmp);
-        Py_DECREF(multmp);
     }
 
     if (addtmp)
     {
         PyObject_CallMethod((PyObject *)self, "setAdd", "O", addtmp);
-        Py_DECREF(addtmp);
     }
 
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
@@ -2714,7 +2559,6 @@ static PyNumberMethods SfMarkerLoop_as_number =
     (binaryfunc)SfMarkerLoop_add,                      /*nb_add*/
     (binaryfunc)SfMarkerLoop_sub,                 /*nb_subtract*/
     (binaryfunc)SfMarkerLoop_multiply,                 /*nb_multiply*/
-    INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
     0,                /*nb_remainder*/
     0,                   /*nb_divmod*/
     0,                   /*nb_power*/
@@ -2728,16 +2572,12 @@ static PyNumberMethods SfMarkerLoop_as_number =
     0,              /*nb_and*/
     0,              /*nb_xor*/
     0,               /*nb_or*/
-    INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
     0,                       /*nb_int*/
     0,                      /*nb_long*/
     0,                     /*nb_float*/
-    INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
-    INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
     (binaryfunc)SfMarkerLoop_inplace_add,              /*inplace_add*/
     (binaryfunc)SfMarkerLoop_inplace_sub,         /*inplace_subtract*/
     (binaryfunc)SfMarkerLoop_inplace_multiply,         /*inplace_multiply*/
-    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
     0,        /*inplace_remainder*/
     0,           /*inplace_power*/
     0,       /*inplace_lshift*/
@@ -2773,7 +2613,7 @@ PyTypeObject SfMarkerLoopType =
     0,                         /*tp_getattro*/
     0,                         /*tp_setattro*/
     0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES,  /*tp_flags*/
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC,  /*tp_flags*/
     "SfMarkerLoop objects. Reads a channel from a soundfile directly from disk.",           /* tp_doc */
     (traverseproc)SfMarkerLoop_traverse,   /* tp_traverse */
     (inquiry)SfMarkerLoop_clear,           /* tp_clear */
